﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Windows;
using System.Windows.Controls;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace ThinkGeo.MapSuite.DisplayCadFileSample
{
    public partial class MainWindow : Window
    {
        private List<LayerItem> layerItems = new List<LayerItem>();
        private LayerItem selectedLayerItem;
        private bool standardStyling;
        private Size imageSize;
        private RectangleShape imageLayerBBOX;

        public MainWindow()
        {
            InitializeComponent();
            imageSize = new Size(2283, 1543);
        }

        private void WindowLoaded(object sender, RoutedEventArgs e)
        {
            imageLayerBBOX = new RectangleShape(-imageSize.Width * .5, imageSize.Height * .5, imageSize.Width * .5, -imageSize.Height * .5);

            map.MapUnit = GeographyUnit.Meter;
           // map.ZoomLevelSet = new PrinterZoomLevelSet(map.MapUnit, PrinterHelper.GetPointsPerGeographyUnit(map.MapUnit));
            //map.CurrentExtent = imageLayerBBOX;

            LayerOverlay layerOverlay = new LayerOverlay();

            GdiPlusRasterLayer gdiPlusRasterLayer = new GdiPlusRasterLayer(@"..\..\App_Data\Jpg\MIA_Miami_International_Airport_FAA_diagram.jpg", imageLayerBBOX);
            gdiPlusRasterLayer.Name = "ImageLayer";
            layerOverlay.Layers.Add("ImageLayer", gdiPlusRasterLayer);

            CadFeatureLayer touristHomeCadLayer = new CadFeatureLayer(@"..\..\App_Data\CAD\Tourist_Home.dwg");
            touristHomeCadLayer.Name = "Tourist_Home";
            touristHomeCadLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = new LineStyle(new GeoPen(GeoColor.SimpleColors.Black, 2));
            touristHomeCadLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = new PointStyle(PointSymbolType.Circle, new GeoSolidBrush(GeoColor.SimpleColors.Yellow), 8);
            touristHomeCadLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = new AreaStyle(new GeoSolidBrush(GeoColor.SimpleColors.Yellow));
            touristHomeCadLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            touristHomeCadLayer.IsVisible = false;
            layerOverlay.Layers.Add(touristHomeCadLayer);
            layerItems.Add(new LayerItem("Tourist_Home", new RectangleShape(-46989.2556896988, 41738.4919000966, -26351.3096719721, 23596.2086137728)));

            CadFeatureLayer miaTerminalCadLayer = new CadFeatureLayer(@"..\..\App_Data\CAD\MIA_Terminal.dwg");
            miaTerminalCadLayer.Name = "MIA_Terminal";
            miaTerminalCadLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = new LineStyle(new GeoPen(GeoColor.SimpleColors.Black, 2));
            miaTerminalCadLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = new PointStyle(PointSymbolType.Circle, new GeoSolidBrush(GeoColor.SimpleColors.Yellow), 8);
            miaTerminalCadLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = new AreaStyle(new GeoSolidBrush(GeoColor.SimpleColors.Yellow));
            miaTerminalCadLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            miaTerminalCadLayer.IsVisible = false;
            layerOverlay.Layers.Add(miaTerminalCadLayer);
            layerItems.Add(new LayerItem("MIA_Terminal", new RectangleShape(884240.730679665, 545933.087865818, 925516.622720834, 509648.521288147)));

            map.Overlays.Add("LayerOverlay", layerOverlay);
            selectedLayerItem = layerItems.FirstOrDefault();
        }

        public List<LayerItem> LayerItems
        {
            get { return layerItems; }
            set { layerItems = value; }
        }

        public LayerItem SelectedLayerItem
        {
            get { return selectedLayerItem; }
            set
            {
                selectedLayerItem = value;
                RefreshSelectedLayer(selectedLayerItem);
            }
        }

        public bool StandardStyling
        {
            get { return standardStyling; }
            set
            {
                standardStyling = value;
                RefreshSelectedLayer(selectedLayerItem);
            }
        }

        private void RefreshSelectedLayer(LayerItem selectedLayer)
        {
            LayerOverlay layerOverlay = (LayerOverlay)map.Overlays["LayerOverlay"];
            foreach (var layer in layerOverlay.Layers)
            {
                layer.IsVisible = false;
            }

            Layer currentLayer = layerOverlay.Layers.Single(a => a.Name.Equals(selectedLayer.Name));
            currentLayer.IsVisible = true;

            if (currentLayer is GdiPlusRasterLayer)
            {
                map.ZoomLevelSet = new PrinterZoomLevelSet(map.MapUnit, PrinterHelper.GetPointsPerGeographyUnit(map.MapUnit));
            }
            else
            {
                ((CadFeatureLayer)currentLayer).StylingType = standardStyling ? CadStylingType.StandardStyling : CadStylingType.EmbeddedStyling;
                map.ZoomLevelSet = new GoogleMapsZoomLevelSet();
            }

            map.CurrentExtent = selectedLayer.BoundingBox;
            map.Refresh();
        }

        private void TabControlSelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (IsLoaded)
            {
                var tabItem = (TabItem)tabControl.SelectedItem;

                if (tabItem.Header.Equals("Display Image"))
                {
                    LayerItem imageLayerItem = new LayerItem("ImageLayer", imageLayerBBOX);
                    RefreshSelectedLayer(imageLayerItem);
                }
                else
                {
                    RefreshSelectedLayer(selectedLayerItem);
                }
            }
        }

        private void btnImageRefreshClick(object sender, RoutedEventArgs e)
        {
            LayerOverlay layerOverlay = (LayerOverlay)map.Overlays["LayerOverlay"];

            imageSize = new Size(Convert.ToDouble(imageWidth.Text), Convert.ToDouble(imageHeight.Text));
            imageLayerBBOX = new RectangleShape(-imageSize.Width * .5, imageSize.Height * .5, imageSize.Width * .5, -imageSize.Height * .5);

            GdiPlusRasterLayer gdiPlusRasterLayer = new GdiPlusRasterLayer(@"..\..\App_Data\Jpg\MIA_Miami_International_Airport_FAA_diagram.jpg", imageLayerBBOX);
            gdiPlusRasterLayer.Name = "ImageLayer";
            layerOverlay.Layers[gdiPlusRasterLayer.Name] = gdiPlusRasterLayer;

            LayerItem imageLayerItem = new LayerItem("ImageLayer", GetImageLayerBBOX());
            RefreshSelectedLayer(imageLayerItem);
        }

        private RectangleShape GetImageLayerBBOX()
        {
            return new RectangleShape(Convert.ToDouble(imageLeft.Text), Convert.ToDouble(imageTop.Text),
                Convert.ToDouble(imageRight.Text), Convert.ToDouble(imageBottom.Text));
        }
    }
}
